=====
Usage
=====

To use `ingredients` in a project::

    >>> from ingredients.ingredients import ingredients
    >>> ingredients(10)
    1.0 cups arepa flour
    1.0 cups cheese
    0.25 cups water
